@@ -1541,6 +1541,7 @@ tracker_data_insert_statement_with_uri (const gchar            *graph,
 		} else {
 			g_set_error (error, TRACKER_DATA_ERROR, TRACKER_DATA_ERROR_UNKNOWN_CLASS,
 			             "Class '%s' not found in the ontology", object);
+			return;
 		}
 	} else if (strcmp (predicate, TRACKER_PREFIX "uri") == 0) {
 		/* internal property tracker:uri, used to change uri of existing element */
@@ -1952,7 +1953,7 @@ format_sql_value_as_string (GString         *sql,
  */
 void
 tracker_data_delete_resource_description (const gchar *graph,
-                                          const gchar *uri,
+                                          const gchar *url,
                                           GError **error)
 {
 	TrackerDBInterface *iface;
@@ -1970,10 +1971,24 @@ tracker_data_delete_resource_description (const gchar *graph,
 	 * that otherwise the query of the outer cursor would be reused by the
 	 * cursors of the inner queries. */
 
-	resource_id = tracker_data_query_resource_id (uri);
-
 	iface = tracker_db_manager_get_db_interface ();
 
+	/* DROP GRAPH <url> - url here is nie:url */
+
+	stmt = tracker_db_interface_create_statement (iface, "SELECT ID FROM \"nie:DataObject\" WHERE \"nie:DataObject\".\"nie:url\" = ?");
+	tracker_db_statement_bind_text (stmt, 0, url);
+	result_set = tracker_db_statement_execute (stmt, NULL);
+	g_object_unref (stmt);
+
+	if (result_set) {
+		tracker_db_result_set_get (result_set, 0, &resource_id, -1);
+		g_object_unref (result_set);
+	} else {
+		/* For fallback to the old behaviour, we could do this here:
+		 * resource_id = tracker_data_query_resource_id (url); */
+		return;
+	}
+
 	properties = tracker_ontology_get_properties (&n_props);
 
 	stmt = tracker_db_interface_create_statement (iface, "SELECT (SELECT Uri FROM Resource WHERE ID = \"rdf:type\") FROM \"rdfs:Resource_rdf:type\" WHERE ID = ?");
@@ -2058,7 +2073,7 @@ tracker_data_delete_resource_description (const gchar *graph,
 					tracker_db_result_set_get (single_result, i++, &value, -1);
 
 					if (value) {
-						tracker_data_delete_statement (graph, uri,
+						tracker_data_delete_statement (graph, url,
 						                               tracker_property_get_uri (property),
 						                               value,
 						                               &new_error);
@@ -2093,7 +2108,7 @@ tracker_data_delete_resource_description (const gchar *graph,
 
 							tracker_db_result_set_get (multi_result, 0, &value, -1);
 
-							tracker_data_delete_statement (graph, uri,
+							tracker_data_delete_statement (graph, url,
 							                               tracker_property_get_uri (property),
 							                               value,
 							                               &new_error);
