@@ -23,7 +23,7 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
-#include <libtracker-common/tracker-sparql-builder.h>
+#include <libtracker-client/tracker-sparql-builder.h>
 
 #include "tracker-miner.h"
 
@@ -57,7 +57,7 @@ struct TrackerMinerFS {
  * @check_directory: Called when a directory should be checked for further processing
  * @check_directory_contents: Called when a directory should be checked for further processing, based on the directory contents.
  * @process_file: Called when the metadata associated to a file is requested.
- * @writeback_file: Called after a writeback event happens on a file.
+ * @ignore_next_update_file: Called after a writeback event happens on a file.
  * @monitor_directory: Called to check whether a directory should be modified.
  * @finished: Called when all processing has been performed.
  *
@@ -68,45 +68,42 @@ struct TrackerMinerFS {
 typedef struct {
 	TrackerMinerClass parent;
 
-	gboolean (* check_file)            (TrackerMinerFS       *fs,
-	                                    GFile                *file);
-	gboolean (* check_directory)       (TrackerMinerFS       *fs,
-	                                    GFile                *file);
-	gboolean (* check_directory_contents) (TrackerMinerFS    *fs,
-	                                       GFile             *parent,
-	                                       GList             *children);
-	gboolean (* process_file)          (TrackerMinerFS       *fs,
-	                                    GFile                *file,
-	                                    TrackerSparqlBuilder *builder,
-	                                    GCancellable         *cancellable);
-	gboolean (* writeback_file)        (TrackerMinerFS       *fs,
-	                                    GFile                *file,
-	                                    TrackerSparqlBuilder *builder,
-	                                    GCancellable         *cancellable);
-
-	gboolean (* monitor_directory)     (TrackerMinerFS       *fs,
-	                                    GFile                *file);
-	void     (* finished)              (TrackerMinerFS       *fs);
+	gboolean (* check_file)               (TrackerMinerFS       *fs,
+                                               GFile                *file);
+	gboolean (* check_directory)          (TrackerMinerFS       *fs,
+                                               GFile                *file);
+	gboolean (* check_directory_contents) (TrackerMinerFS       *fs,
+	                                       GFile                *parent,
+	                                       GList                *children);
+	gboolean (* process_file)             (TrackerMinerFS       *fs,
+                                               GFile                *file,
+                                               TrackerSparqlBuilder *builder,
+                                               GCancellable         *cancellable);
+	gboolean (* ignore_next_update_file)  (TrackerMinerFS       *fs,
+                                               GFile                *file,
+                                               TrackerSparqlBuilder *builder,
+                                               GCancellable         *cancellable);
+	gboolean (* monitor_directory)        (TrackerMinerFS       *fs,
+                                               GFile                *file);
+	void     (* finished)                 (TrackerMinerFS       *fs);
 } TrackerMinerFSClass;
 
 GType    tracker_miner_fs_get_type         (void) G_GNUC_CONST;
 
-void     tracker_miner_fs_add_directory    (TrackerMinerFS *fs,
+void     tracker_miner_fs_directory_add    (TrackerMinerFS *fs,
                                             GFile          *file,
                                             gboolean        recurse);
-gboolean tracker_miner_fs_remove_directory (TrackerMinerFS *fs,
+gboolean tracker_miner_fs_directory_remove (TrackerMinerFS *fs,
                                             GFile          *file);
-
+void     tracker_miner_fs_file_add         (TrackerMinerFS *fs,
+                                            GFile          *file);
+void     tracker_miner_fs_file_notify      (TrackerMinerFS *fs,
+                                            GFile          *file,
+                                            const GError   *error);
 void     tracker_miner_fs_set_throttle     (TrackerMinerFS *fs,
                                             gdouble         throttle);
 gdouble  tracker_miner_fs_get_throttle     (TrackerMinerFS *fs);
 
-void     tracker_miner_fs_notify_file      (TrackerMinerFS *fs,
-                                            GFile          *file,
-                                            const GError   *error);
-void     tracker_miner_fs_add_file         (TrackerMinerFS *fs,
-                                            GFile          *file);
-
 G_END_DECLS
 
 #endif /* __LIBTRACKERMINER_MINER_FS_H__ */
