@@ -327,7 +327,7 @@ tags_view_query_files_for_tag_id_cb (GPtrArray *result,
 
 		/* We automatically remove the tag */
 		query = g_strdup_printf ("DELETE { "
-		                         "  <%s> a nao:Tag "
+		                         "  <%s> a rdfs:Resource "
 		                         "}",
 		                         td->tag_id);
 
@@ -851,7 +851,8 @@ tags_view_create_ui (TrackerTagsView *tv)
 					      "WHERE {"
 					      "  ?u a nao:Tag ;"
 					      "  nao:prefLabel ?t ."
-					      "}",
+					      "}"
+	                                      "ORDER BY ?t",
 					      tags_view_add_tags_cb, tv);
 
 	gtk_widget_show_all (GTK_WIDGET (tv));
