@@ -1,4 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * Copyright (C) 2006, Laurent Aguerreche (laurent.aguerreche@free.fr)
  * Copyright (C) 2007, Mr Jamie McCracken (jamiemcc@gnome.org)
@@ -41,8 +40,9 @@ long long int llroundl(long double x);
 #include <libtracker-common/tracker-ontology.h>
 #include <libtracker-common/tracker-utils.h>
 
+#include <libtracker-extract/tracker-extract.h>
+
 #include "tracker-albumart.h"
-#include "tracker-main.h"
 #include "tracker-dbus.h"
 
 /* We wait this long (seconds) for NULL state before freeing */
@@ -99,34 +99,45 @@ typedef struct {
 
 	GstBus         *bus;
 
-	ExtractMime	mime;
+	ExtractMime     mime;
 
 
 	/* Decodebin elements and properties*/
-	GstElement     *bin;	
+	GstElement     *bin;
 	GList          *fsinks;
 
 	gint64          duration;
-	gint		video_height;
-	gint		video_width;
-	gint		video_fps_n;
-	gint		video_fps_d;
-	gint		audio_channels;
-	gint		audio_samplerate;
+	gint            video_height;
+	gint            video_width;
+	gint            video_fps_n;
+	gint            video_fps_d;
+	gint            audio_channels;
+	gint            audio_samplerate;
+	gint            aspect_ratio;
 
 	/* Tags and data */
 	GstTagList     *tagcache;
 
+	gboolean        is_content_encrypted;
+
 	unsigned char  *album_art_data;
 	guint           album_art_size;
 	const gchar    *album_art_mime;
 
 } MetadataExtractor;
 
-static void extract_gstreamer_audio (const gchar *uri, TrackerSparqlBuilder *metadata);
-static void extract_gstreamer_video (const gchar *uri, TrackerSparqlBuilder *metadata);
-static void extract_gstreamer_image (const gchar *uri, TrackerSparqlBuilder *metadata);
-static void extract_gstreamer_3gpp (const gchar *uri, TrackerSparqlBuilder *metadata);
+static void extract_gstreamer_audio (const gchar          *uri,
+                                     TrackerSparqlBuilder *preupdate,
+                                     TrackerSparqlBuilder *metadata);
+static void extract_gstreamer_video (const gchar          *uri,
+                                     TrackerSparqlBuilder *preupdate,
+                                     TrackerSparqlBuilder *metadata);
+static void extract_gstreamer_image (const gchar          *uri,
+                                     TrackerSparqlBuilder *preupdate,
+                                     TrackerSparqlBuilder *metadata);
+static void extract_gstreamer_3gpp  (const gchar          *uri,
+                                     TrackerSparqlBuilder *preupdate,
+                                     TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
 	{ "audio/*", extract_gstreamer_audio },
@@ -146,9 +157,9 @@ const gboolean use_tagreadbin = FALSE;
 
 static void
 add_int64_info (TrackerSparqlBuilder *metadata,
-		const gchar *uri,
-		const gchar *key,
-		gint64	    info)
+                const gchar *uri,
+                const gchar *key,
+                gint64      info)
 {
 	tracker_sparql_builder_predicate (metadata, key);
 	tracker_sparql_builder_object_int64 (metadata, info);
@@ -156,9 +167,9 @@ add_int64_info (TrackerSparqlBuilder *metadata,
 
 static void
 add_uint_info (TrackerSparqlBuilder *metadata,
-	       const gchar *uri,
-	       const gchar *key,
-	       guint	   info)
+               const gchar *uri,
+               const gchar *key,
+               guint       info)
 {
 	tracker_sparql_builder_predicate (metadata, key);
 	tracker_sparql_builder_object_int64 (metadata, info);
@@ -166,12 +177,12 @@ add_uint_info (TrackerSparqlBuilder *metadata,
 
 static void
 add_string_gst_tag (TrackerSparqlBuilder *metadata,
-		    const gchar          *uri,
-		    const gchar          *key,
-		    GstTagList	         *tag_list,
-		    const gchar          *tag)
+                    const gchar          *uri,
+                    const gchar          *key,
+                    GstTagList           *tag_list,
+                    const gchar          *tag)
 {
-	gchar	 *s;
+	gchar    *s;
 	gboolean  ret;
 
 	s = NULL;
@@ -189,13 +200,13 @@ add_string_gst_tag (TrackerSparqlBuilder *metadata,
 
 static void
 add_uint_gst_tag (TrackerSparqlBuilder   *metadata,
-		  const gchar *uri,
-		  const gchar *key,
-		  GstTagList  *tag_list,
-		  const gchar *tag)
+                  const gchar *uri,
+                  const gchar *key,
+                  GstTagList  *tag_list,
+                  const gchar *tag)
 {
 	gboolean ret;
-	guint	 n;
+	guint    n;
 
 	ret = gst_tag_list_get_uint (tag_list, tag, &n);
 
@@ -207,13 +218,13 @@ add_uint_gst_tag (TrackerSparqlBuilder   *metadata,
 
 static void
 add_int_gst_tag (TrackerSparqlBuilder   *metadata,
-		 const gchar *uri,
-		 const gchar *key,
-		 GstTagList  *tag_list,
-		 const gchar *tag)
+                 const gchar *uri,
+                 const gchar *key,
+                 GstTagList  *tag_list,
+                 const gchar *tag)
 {
 	gboolean ret;
-	gint	 n;
+	gint     n;
 
 	ret = gst_tag_list_get_int (tag_list, tag, &n);
 
@@ -224,14 +235,14 @@ add_int_gst_tag (TrackerSparqlBuilder   *metadata,
 }
 
 static void
-add_double_gst_tag (TrackerSparqlBuilder	*metadata,
-		    const gchar *uri,
-		    const gchar *key,
-		    GstTagList	*tag_list,
-		    const gchar *tag)
+add_double_gst_tag (TrackerSparqlBuilder        *metadata,
+                    const gchar *uri,
+                    const gchar *key,
+                    GstTagList  *tag_list,
+                    const gchar *tag)
 {
 	gboolean ret;
-	gdouble	 n;
+	gdouble          n;
 
 	ret = gst_tag_list_get_double (tag_list, tag, &n);
 
@@ -243,13 +254,13 @@ add_double_gst_tag (TrackerSparqlBuilder	*metadata,
 
 static void
 add_fraction_gst_tag (TrackerSparqlBuilder         *metadata,
-		      const gchar       *uri,
-		      const gchar       *key,
-		      GstTagList	*tag_list,
-		      const gchar       *tag)
+                      const gchar       *uri,
+                      const gchar       *key,
+                      GstTagList        *tag_list,
+                      const gchar       *tag)
 {
 	gboolean ret;
-	GValue	 n = {0,};
+	GValue   n = {0,};
 	gfloat   f;
 
 	ret = gst_tag_list_copy_value (&n, tag_list, tag);
@@ -265,21 +276,21 @@ add_fraction_gst_tag (TrackerSparqlBuilder         *metadata,
 
 static void
 add_y_date_gst_tag (TrackerSparqlBuilder  *metadata,
-		    const gchar *uri,
-		    const gchar *key,
-		    GstTagList  *tag_list,
-		    const gchar *tag)
+                    const gchar *uri,
+                    const gchar *key,
+                    GstTagList  *tag_list,
+                    const gchar *tag)
 {
-	GDate	 *date;
+	GDate    *date;
 	gboolean  ret;
 
 	date = NULL;
 	ret = gst_tag_list_get_date (tag_list, tag, &date);
 
 	if (ret) {
-		gchar buf[10];
+		gchar buf[25];
 
-		if (g_date_strftime (buf, 10, "%Y", date)) {
+		if (g_date_strftime (buf, 25, "%Y-%m-%dT%H:%M:%S%z", date)) {
 			tracker_sparql_builder_predicate (metadata, key);
 			tracker_sparql_builder_object_unvalidated (metadata, buf);
 		}
@@ -292,13 +303,13 @@ add_y_date_gst_tag (TrackerSparqlBuilder  *metadata,
 
 static void
 add_time_gst_tag (TrackerSparqlBuilder   *metadata,
-		  const gchar *uri,
-		  const gchar *key,
-		  GstTagList  *tag_list,
-		  const gchar *tag)
+                  const gchar *uri,
+                  const gchar *key,
+                  GstTagList  *tag_list,
+                  const gchar *tag)
 {
 	gboolean ret;
-	guint64	 n;
+	guint64          n;
 
 	ret = gst_tag_list_get_uint64 (tag_list, tag, &n);
 
@@ -334,9 +345,9 @@ get_embedded_album_art(MetadataExtractor *extractor)
 			caps_struct = gst_caps_get_structure (buffer->caps, 0);
 
 			gst_structure_get_enum (caps_struct,
-						"image-type",
-						GST_TYPE_TAG_IMAGE_TYPE,
-						&type);
+			                        "image-type",
+			                        GST_TYPE_TAG_IMAGE_TYPE,
+			                        &type);
 
 			if ((type == GST_TAG_IMAGE_TYPE_FRONT_COVER)||
 			    ((type == GST_TAG_IMAGE_TYPE_UNDEFINED)&&(extractor->album_art_size == 0))) {
@@ -378,13 +389,15 @@ get_embedded_album_art(MetadataExtractor *extractor)
 
 static void
 extract_stream_metadata_tagreadbin (MetadataExtractor *extractor,
-				    const gchar       *uri,
-				    TrackerSparqlBuilder         *metadata)
+                                    const gchar       *uri,
+                                    TrackerSparqlBuilder         *metadata)
 {
 	if (extractor->mime != EXTRACT_MIME_IMAGE) {
-		add_uint_gst_tag (metadata, uri, "nfo:channels", extractor->tagcache, GST_TAG_CHANNEL);
-		add_uint_gst_tag (metadata, uri, "nfo:sampleRate", extractor->tagcache, GST_TAG_RATE);
+		add_int_gst_tag (metadata, uri, "nfo:channels", extractor->tagcache, GST_TAG_CHANNEL);
+		add_int_gst_tag (metadata, uri, "nfo:sampleRate", extractor->tagcache, GST_TAG_RATE);
 		add_time_gst_tag (metadata, uri, "nfo:duration", extractor->tagcache, GST_TAG_DURATION);
+	} else {
+		add_int_gst_tag (metadata, uri, "nfo:aspectRatio", extractor->tagcache, GST_TAG_PIXEL_RATIO);
 	}
 
 	add_int_gst_tag (metadata, uri, "nfo:height", extractor->tagcache, GST_TAG_HEIGHT);
@@ -397,10 +410,11 @@ extract_stream_metadata_tagreadbin (MetadataExtractor *extractor,
 
 static void
 extract_stream_metadata_decodebin (MetadataExtractor *extractor,
-				   const gchar       *uri,
-				   TrackerSparqlBuilder         *metadata)
+                                   const gchar       *uri,
+                                   TrackerSparqlBuilder         *metadata)
 {
 	if (extractor->mime != EXTRACT_MIME_IMAGE) {
+
 		if (extractor->audio_channels >= 0) {
 			add_uint_info (metadata, uri, "nfo:channels", extractor->audio_channels);
 		}
@@ -412,6 +426,10 @@ extract_stream_metadata_decodebin (MetadataExtractor *extractor,
 		if (extractor->duration >= 0) {
 			add_int64_info (metadata, uri, "nfo:duration", extractor->duration);
 		}
+	} else {
+		if (extractor->aspect_ratio >= 0) {
+			add_uint_info (metadata, uri, "nfo:aspectRatio", extractor->aspect_ratio);
+		}
 	}
 
 	if (extractor->video_height >= 0) {
@@ -425,28 +443,34 @@ extract_stream_metadata_decodebin (MetadataExtractor *extractor,
 	if (extractor->mime == EXTRACT_MIME_VIDEO) {
 		if (extractor->video_fps_n >= 0 && extractor->video_fps_d >= 0) {
 			add_uint_info (metadata,
-				       uri, "nfo:frameRate",
-				       ((extractor->video_fps_n + extractor->video_fps_d / 2) /
-					extractor->video_fps_d));
+			               uri, "nfo:frameRate",
+			               ((extractor->video_fps_n + extractor->video_fps_d / 2) /
+			                extractor->video_fps_d));
 		}
 	}
 }
 
 static void
 extract_metadata (MetadataExtractor      *extractor,
-		  const gchar            *uri,
-		  TrackerSparqlBuilder   *metadata,
-		  gchar                 **album,
-		  gchar                 **scount)
+                  const gchar            *uri,
+                  TrackerSparqlBuilder   *preupdate,
+                  TrackerSparqlBuilder   *metadata,
+                  gchar                 **album,
+                  gchar                 **scount)
 {
 	gchar *s;
 	gboolean ret;
 	gint count;
+	gboolean needs_audio = FALSE;
 
 	g_return_if_fail (extractor != NULL);
 	g_return_if_fail (metadata != NULL);
 
 	if (extractor->tagcache) {
+		gchar *performer_uri = NULL;
+		gchar *composer_uri = NULL;
+		gchar *album_uri = NULL;
+
 		if (extractor->mime == EXTRACT_MIME_3GPP) {
 			gchar *video_codec = NULL, *audio_codec = NULL;
 
@@ -474,22 +498,16 @@ extract_metadata (MetadataExtractor      *extractor,
 			s = tracker_coalesce (2, performer, artist);
 
 			if (s) {
-				gchar *canonical_uri = tracker_uri_printf_escaped ("urn:artist:%s", s);
+				performer_uri = tracker_uri_printf_escaped ("urn:artist:%s", s);
 
-				tracker_sparql_builder_subject_iri (metadata, canonical_uri);
-				tracker_sparql_builder_predicate (metadata, "a");
-				tracker_sparql_builder_object (metadata, "nmm:Artist");
+				tracker_sparql_builder_insert_open (preupdate, NULL);
+				tracker_sparql_builder_subject_iri (preupdate, performer_uri);
+				tracker_sparql_builder_predicate (preupdate, "a");
+				tracker_sparql_builder_object (preupdate, "nmm:Artist");
+				tracker_sparql_builder_predicate (preupdate, "nmm:artistName");
+				tracker_sparql_builder_object_unvalidated (preupdate, s);
+				tracker_sparql_builder_insert_close (preupdate);
 
-				if (extractor->mime == EXTRACT_MIME_AUDIO) {
-					tracker_sparql_builder_object (metadata, "nmm:performer");
-				} else {
-					tracker_sparql_builder_object (metadata, "nmm:leadActor");
-				}
-
-				tracker_sparql_builder_predicate (metadata, "nmm:artistName");
-				tracker_sparql_builder_object_unvalidated (metadata, s);
-
-				g_free (canonical_uri);
 				g_free (s);
 			}
 
@@ -497,66 +515,124 @@ extract_metadata (MetadataExtractor      *extractor,
 			gst_tag_list_get_string (extractor->tagcache, GST_TAG_COMPOSER, &s);
 
 			if (s) {
-				gchar *canonical_uri = tracker_uri_printf_escaped ("urn:artist:%s", s);
+				composer_uri = tracker_uri_printf_escaped ("urn:artist:%s", s);
 
-				tracker_sparql_builder_subject_iri (metadata, canonical_uri);
-				tracker_sparql_builder_predicate (metadata, "a");
-				tracker_sparql_builder_object (metadata, "nmm:Artist");
+				tracker_sparql_builder_insert_open (preupdate, NULL);
 
-				if (extractor->mime == EXTRACT_MIME_AUDIO) {
-					tracker_sparql_builder_object (metadata, "nmm:composer");
-				} else {
-					tracker_sparql_builder_object (metadata, "nmm:director");
-				}
+				tracker_sparql_builder_subject_iri (preupdate, composer_uri);
+				tracker_sparql_builder_predicate (preupdate, "a");
+				tracker_sparql_builder_object (preupdate, "nmm:Artist");
 
-				tracker_sparql_builder_predicate (metadata, "nmm:artistName");
-				tracker_sparql_builder_object_unvalidated (metadata, s);
+				tracker_sparql_builder_predicate (preupdate, "nmm:artistName");
+				tracker_sparql_builder_object_unvalidated (preupdate, s);
+
+				tracker_sparql_builder_insert_close (preupdate);
 
-				g_free (canonical_uri);
 				g_free (s);
 			}
 
-			s = NULL;
-			gst_tag_list_get_string (extractor->tagcache, GST_TAG_GENRE, &s);
-			if (s && strcmp (s, "Unknown") != 0) {
-				tracker_sparql_builder_predicate (metadata, "nfo:genre");
-				tracker_sparql_builder_object_unvalidated (metadata, s);
-			}
-			g_free (s);
 		}
 
-		if (extractor->mime == EXTRACT_MIME_AUDIO) {
-			/* Audio */
-			s = NULL;
-			gst_tag_list_get_string (extractor->tagcache, GST_TAG_ALBUM, &s);
-			if (s) {
-				gchar *urn;
+		/* Audio */
+		s = NULL;
+		gst_tag_list_get_string (extractor->tagcache, GST_TAG_ALBUM, &s);
+		if (s) {
+			gboolean has_it;
+			guint count;
 
-				urn = tracker_uri_printf_escaped ("urn:album:%s", s);
-				tracker_sparql_builder_subject_iri (metadata, urn);
-				tracker_sparql_builder_predicate (metadata, "a");
-				tracker_sparql_builder_object (metadata, "nmm:MusicAlbum");
-				tracker_sparql_builder_predicate (metadata, "nmm:albumTitle");
-				tracker_sparql_builder_object_unvalidated (metadata, s);
-				add_uint_gst_tag (metadata, urn, "nmm:albumTrackCount", extractor->tagcache, GST_TAG_TRACK_COUNT);
-				*album = s;
+			needs_audio = TRUE;
 
-				g_free (urn);
+			album_uri = tracker_uri_printf_escaped ("urn:album:%s", s);
+
+			tracker_sparql_builder_insert_open (preupdate, NULL);
+
+			tracker_sparql_builder_subject_iri (preupdate, album_uri);
+			tracker_sparql_builder_predicate (preupdate, "a");
+			tracker_sparql_builder_object (preupdate, "nmm:MusicAlbum");
+			tracker_sparql_builder_predicate (preupdate, "nmm:albumTitle");
+			tracker_sparql_builder_object_unvalidated (preupdate, s);
+
+			tracker_sparql_builder_insert_close (preupdate);
+
+			has_it = gst_tag_list_get_uint (extractor->tagcache, 
+			                                GST_TAG_TRACK_COUNT, 
+			                                &count);
+
+			if (has_it) {
+				tracker_sparql_builder_delete_open (preupdate, NULL);
+				tracker_sparql_builder_subject_iri (preupdate, album_uri);
+				tracker_sparql_builder_predicate (preupdate, "nmm:albumTrackCount");
+				tracker_sparql_builder_object_variable (preupdate, "unknown");
+				tracker_sparql_builder_delete_close (preupdate);
+
+				tracker_sparql_builder_where_open (preupdate);
+				tracker_sparql_builder_subject_iri (preupdate, album_uri);
+				tracker_sparql_builder_predicate (preupdate, "nmm:albumTrackCount");
+				tracker_sparql_builder_object_variable (preupdate, "unknown");
+				tracker_sparql_builder_where_close (preupdate);
+
+				tracker_sparql_builder_insert_open (preupdate, NULL);
+
+				tracker_sparql_builder_subject_iri (preupdate, album_uri);
+				tracker_sparql_builder_predicate (preupdate, "nmm:albumTrackCount");
+				tracker_sparql_builder_object_int64 (preupdate, count);
+
+				tracker_sparql_builder_insert_close (preupdate);
 			}
+
+			has_it = gst_tag_list_get_uint (extractor->tagcache, 
+			                                GST_TAG_ALBUM_VOLUME_NUMBER, 
+			                                &count);
+
+			if (has_it) {
+				tracker_sparql_builder_delete_open (preupdate, NULL);
+				tracker_sparql_builder_subject_iri (preupdate, album_uri);
+				tracker_sparql_builder_predicate (preupdate, "nmm:setNumber");
+				tracker_sparql_builder_object_variable (preupdate, "unknown");
+				tracker_sparql_builder_delete_close (preupdate);
+
+				tracker_sparql_builder_where_open (preupdate);
+				tracker_sparql_builder_subject_iri (preupdate, album_uri);
+				tracker_sparql_builder_predicate (preupdate, "nmm:setNumber");
+				tracker_sparql_builder_object_variable (preupdate, "unknown");
+				tracker_sparql_builder_where_close (preupdate);
+
+				tracker_sparql_builder_insert_open (preupdate, NULL);
+
+				tracker_sparql_builder_subject_iri (preupdate, album_uri);
+				tracker_sparql_builder_predicate (preupdate, "nmm:setNumber");
+				tracker_sparql_builder_object_int64 (preupdate, count);
+
+				tracker_sparql_builder_insert_close (preupdate);
+			}
+
+			*album = s;
 		}
 
-		tracker_sparql_builder_subject_iri (metadata, uri);
+		if (extractor->mime == EXTRACT_MIME_AUDIO)
+			needs_audio = TRUE;
+
 		tracker_sparql_builder_predicate (metadata, "a");
 
-		if (extractor->mime == EXTRACT_MIME_AUDIO) {
+		if (needs_audio) {
 			tracker_sparql_builder_object (metadata, "nmm:MusicPiece");
 			tracker_sparql_builder_object (metadata, "nfo:Audio");
-		} else if (extractor->mime == EXTRACT_MIME_VIDEO) {
+		} 
+
+		if (extractor->mime == EXTRACT_MIME_VIDEO) {
 			tracker_sparql_builder_object (metadata, "nmm:Video");
-		} else {
+		} else if (!needs_audio) {
 			tracker_sparql_builder_object (metadata, "nfo:Image");
 		}
 
+		s = NULL;
+		gst_tag_list_get_string (extractor->tagcache, GST_TAG_GENRE, &s);
+		if (s && strcmp (s, "Unknown") != 0) {
+			tracker_sparql_builder_predicate (metadata, "nfo:genre");
+			tracker_sparql_builder_object_unvalidated (metadata, s);
+		}
+		g_free (s);
+
 		add_string_gst_tag (metadata, uri, "nie:title", extractor->tagcache, GST_TAG_TITLE);
 		add_string_gst_tag (metadata, uri, "nie:copyright", extractor->tagcache, GST_TAG_COPYRIGHT);
 		add_string_gst_tag (metadata, uri, "nie:license", extractor->tagcache, GST_TAG_LICENSE);
@@ -564,11 +640,26 @@ extract_metadata (MetadataExtractor      *extractor,
 		add_y_date_gst_tag (metadata, uri, "nie:contentCreated", extractor->tagcache, GST_TAG_DATE);
 		add_string_gst_tag (metadata, uri, "nie:comment", extractor->tagcache, GST_TAG_COMMENT);
 
-		if (extractor->mime == EXTRACT_MIME_VIDEO) {
-			add_string_gst_tag (metadata, uri, "dc:source", extractor->tagcache, GST_TAG_CLASSIFICATION);
+		if (extractor->is_content_encrypted) {
+			tracker_sparql_builder_predicate (metadata, "nfo:isContentEncrypted");
+			tracker_sparql_builder_object_boolean (metadata, TRUE);
 		}
 
-		if (extractor->mime == EXTRACT_MIME_AUDIO) {
+		if (extractor->mime == EXTRACT_MIME_VIDEO) {
+			add_string_gst_tag (metadata, uri, "dc:source", extractor->tagcache, GST_TAG_CLASSIFICATION);
+
+			if (performer_uri) {
+				tracker_sparql_builder_predicate (metadata, "nmm:leadActor");
+				tracker_sparql_builder_object_iri (metadata, performer_uri);
+			}
+
+			if (composer_uri) {
+				tracker_sparql_builder_predicate (metadata, "nmm:director");
+				tracker_sparql_builder_object_iri (metadata, composer_uri);
+			}
+		}
+
+		if (needs_audio) {
 			/* Audio */
 			ret = gst_tag_list_get_uint (extractor->tagcache, GST_TAG_TRACK_COUNT, &count);
 			if (ret) {
@@ -576,17 +667,36 @@ extract_metadata (MetadataExtractor      *extractor,
 			}
 
 			add_uint_gst_tag   (metadata, uri, "nmm:trackNumber", extractor->tagcache, GST_TAG_TRACK_NUMBER);
-			add_uint_gst_tag   (metadata, uri, "nmm:setNumber", extractor->tagcache, GST_TAG_ALBUM_VOLUME_NUMBER);
 
 			add_double_gst_tag (metadata, uri, "nfo:gain", extractor->tagcache, GST_TAG_TRACK_GAIN);
 			add_double_gst_tag (metadata, uri, "nfo:peakGain", extractor->tagcache, GST_TAG_TRACK_PEAK);
 			add_double_gst_tag (metadata, uri, "nfo:albumGain", extractor->tagcache, GST_TAG_ALBUM_GAIN);
 			add_double_gst_tag (metadata, uri, "nfo:albumPeakGain", extractor->tagcache, GST_TAG_ALBUM_PEAK);
+
+			if (performer_uri) {
+				tracker_sparql_builder_predicate (metadata, "nmm:performer");
+				tracker_sparql_builder_object_iri (metadata, performer_uri);
+			}
+
+			if (composer_uri) {
+				tracker_sparql_builder_predicate (metadata, "nmm:composer");
+				tracker_sparql_builder_object_iri (metadata, composer_uri);
+			}
+
+			if (album_uri) {
+				tracker_sparql_builder_predicate (metadata, "nmm:musicAlbum");
+				tracker_sparql_builder_object_iri (metadata, album_uri);
+			}
 		}
 
+		g_free (performer_uri);
+		g_free (composer_uri);
+		g_free (album_uri);
+
 		add_string_gst_tag (metadata, uri, "nfo:codec", extractor->tagcache, GST_TAG_AUDIO_CODEC);
 	}
 
+
 	if (use_tagreadbin) {
 		extract_stream_metadata_tagreadbin (extractor, uri, metadata);
 	} else {
@@ -618,16 +728,16 @@ dbin_dpad_cb (GstElement* e, GstPad* pad, gboolean cont, gpointer data_)
 	GValue             val = {0, };
 
 	fsink = gst_element_factory_make ("fakesink", NULL);
-	
+
 	/* We increase the preroll buffer so we get duration (one frame not enough)*/
 	g_value_init (&val, G_TYPE_INT);
-	g_value_set_int (&val, 51); 
+	g_value_set_int (&val, 51);
 	g_object_set_property (G_OBJECT (fsink), "preroll-queue-len", &val);
 	g_value_unset (&val);
 
 	extractor->fsinks = g_list_append (extractor->fsinks, fsink);
 	gst_element_set_state (fsink, GST_STATE_PAUSED);
-	
+
 	gst_bin_add (GST_BIN (extractor->pipeline), fsink);
 	fsinkpad = gst_element_get_static_pad (fsink, "sink");
 	gst_pad_link (pad, fsinkpad);
@@ -637,7 +747,7 @@ dbin_dpad_cb (GstElement* e, GstPad* pad, gboolean cont, gpointer data_)
 static guint64
 get_media_duration (MetadataExtractor *extractor)
 {
-	gint64	  duration;
+	gint64    duration;
 	GstFormat fmt;
 
 	g_return_val_if_fail (extractor, -1);
@@ -646,10 +756,10 @@ get_media_duration (MetadataExtractor *extractor)
 	fmt = GST_FORMAT_TIME;
 
 	duration = -1;
-	
+
 	if (gst_element_query_duration (extractor->pipeline,
-					&fmt,
-					&duration) &&
+	                                &fmt,
+	                                &duration) &&
 	    duration >= 0) {
 		return duration / GST_SECOND;
 	} else {
@@ -664,21 +774,21 @@ add_stream_tag (void *obj, void *data_)
 	GstElement        *fsink     = (GstElement *) obj;
 
 	GstStructure      *s         = NULL;
-	GstCaps	          *caps      = NULL;
+	GstCaps                   *caps      = NULL;
 
 	if ((caps = GST_PAD_CAPS (fsink))) {
 		s = gst_caps_get_structure (caps, 0);
-		
+
 		if (s) {
 			if (g_strrstr (gst_structure_get_name (s), "audio")) {
 				if ( ( (extractor->audio_channels != -1) &&
 				       (extractor->audio_samplerate != -1) ) ||
 				     !( (gst_structure_get_int (s,
-								"channels",
-								&extractor->audio_channels) ) &&
-					(gst_structure_get_int (s,
-								"rate",
-								&extractor->audio_samplerate)) ) ) {
+				                                "channels",
+				                                &extractor->audio_channels) ) &&
+				        (gst_structure_get_int (s,
+				                                "rate",
+				                                &extractor->audio_samplerate)) ) ) {
 					return;
 				}
 			} else if (g_strrstr (gst_structure_get_name (s), "video")) {
@@ -687,11 +797,12 @@ add_stream_tag (void *obj, void *data_)
 				       (extractor->video_width != -1) &&
 				       (extractor->video_height != -1) ) ||
 				     !( (gst_structure_get_fraction (s,
-								     "framerate",
-								     &extractor->video_fps_n,
-								     &extractor->video_fps_d) ) &&
-					(gst_structure_get_int (s, "width", &extractor->video_width)) &&
-					(gst_structure_get_int (s, "height", &extractor->video_height)))) {
+				                                     "framerate",
+				                                     &extractor->video_fps_n,
+				                                     &extractor->video_fps_d) ) &&
+				        (gst_structure_get_int (s, "width", &extractor->video_width)) &&
+				        (gst_structure_get_int (s, "height", &extractor->video_height)) &&
+				        (gst_structure_get_int (s, "pixel-aspect-ratio", &extractor->aspect_ratio)))) {
 					return;
 				}
 			}
@@ -712,8 +823,8 @@ add_tags (GstTagList *new_tags, MetadataExtractor *extractor)
 	GstTagList   *result;
 
 	result = gst_tag_list_merge (extractor->tagcache,
-				     new_tags,
-				     GST_TAG_MERGE_KEEP);
+	                             new_tags,
+	                             GST_TAG_MERGE_KEEP);
 
 	if (extractor->tagcache) {
 		gst_tag_list_free (extractor->tagcache);
@@ -725,9 +836,9 @@ add_tags (GstTagList *new_tags, MetadataExtractor *extractor)
 
 static gboolean
 poll_for_ready (MetadataExtractor *extractor,
-		GstState state,
-		gboolean ready_with_state,
-		gboolean ready_with_eos)
+                GstState state,
+                gboolean ready_with_state,
+                gboolean ready_with_eos)
 {
 	gint64              timeout   = 5 * GST_SECOND;
 	GstBus             *bus       = extractor->bus;
@@ -738,21 +849,21 @@ poll_for_ready (MetadataExtractor *extractor,
 	while (TRUE) {
 		GstMessage *message;
 		GstElement *src;
-		
+
 		message = gst_bus_timed_pop (bus, timeout);
-		
+
 		if (!message) {
 			g_warning ("Pipeline timed out");
 			return FALSE;
 		}
-		
+
 		src = (GstElement*)GST_MESSAGE_SRC (message);
-		
+
 		switch (GST_MESSAGE_TYPE (message)) {
 		case GST_MESSAGE_STATE_CHANGED: {
 			if (ready_with_state) {
 				GstState old, new, pending;
-				
+
 				if (src == extractor->pipeline) {
 					gst_message_parse_state_changed (message, &old, &new, &pending);
 					if (new == state) {
@@ -768,6 +879,22 @@ poll_for_ready (MetadataExtractor *extractor,
 			gchar  *error_message;
 
 			gst_message_parse_error (message, &lerror, &error_message);
+
+#if (GST_VERSION_MICRO >= 20)
+			if (lerror->domain == GST_STREAM_ERROR) {
+				if (lerror->code == GST_STREAM_ERROR_DECRYPT ||
+				    lerror->code == GST_STREAM_ERROR_DECRYPT_NOKEY) {
+					/* also extract metadata from encrypted streams */
+
+					extractor->is_content_encrypted = TRUE;
+
+					g_free (error_message);
+					g_error_free (lerror);
+					break;
+				}
+			}
+#endif
+
 			gst_message_unref (message);
 			g_warning ("Got error :%s", error_message);
 			g_free (error_message);
@@ -797,12 +924,12 @@ poll_for_ready (MetadataExtractor *extractor,
 			/* Nothing to do here */
 			break;
 		}
-		
+
 		gst_message_unref (message);
 	}
-	
+
 	g_assert_not_reached ();
-	
+
 	return FALSE;
 }
 
@@ -810,7 +937,7 @@ static GstElement *
 create_decodebin_pipeline (MetadataExtractor *extractor, const gchar *uri)
 {
 	GstElement *pipeline = NULL;
-	
+
 	GstElement *filesrc  = NULL;
 	GstElement *bin      = NULL;
 
@@ -834,11 +961,11 @@ create_decodebin_pipeline (MetadataExtractor *extractor, const gchar *uri)
 		return FALSE;
 	}
 
-	id = g_signal_connect (G_OBJECT (bin), 
-			       "new-decoded-pad",
-			       G_CALLBACK (dbin_dpad_cb), 
-			       extractor);
-	
+	id = g_signal_connect (G_OBJECT (bin),
+	                       "new-decoded-pad",
+	                       G_CALLBACK (dbin_dpad_cb),
+	                       extractor);
+
 	gst_bin_add (GST_BIN (pipeline), filesrc);
 	gst_bin_add (GST_BIN (pipeline), bin);
 
@@ -872,8 +999,9 @@ create_tagreadbin_pipeline (MetadataExtractor *extractor, const gchar *uri)
 
 static void
 tracker_extract_gstreamer (const gchar *uri,
-			   TrackerSparqlBuilder  *metadata,
-			   ExtractMime	type)
+                           TrackerSparqlBuilder  *preupdate,
+                           TrackerSparqlBuilder  *metadata,
+                           ExtractMime  type)
 {
 	MetadataExtractor *extractor;
 	gchar *album, *scount;
@@ -893,7 +1021,7 @@ tracker_extract_gstreamer (const gchar *uri,
 	extractor->mime         = type;
 
 	extractor->tagcache     = NULL;
-	
+
 	extractor->album_art_data = NULL;
 	extractor->album_art_size = 0;
 	extractor->album_art_mime = NULL;
@@ -905,6 +1033,7 @@ tracker_extract_gstreamer (const gchar *uri,
 	extractor->video_fps_n = extractor->video_fps_d = -1;
 	extractor->video_height = extractor->video_width = -1;
 	extractor->audio_channels = -1;
+	extractor->aspect_ratio = -1;
 	extractor->audio_samplerate = -1;
 
 	if (use_tagreadbin) {
@@ -924,7 +1053,7 @@ tracker_extract_gstreamer (const gchar *uri,
 		if (!poll_for_ready (extractor, GST_STATE_PLAYING, FALSE, TRUE)) {
 			g_warning ("Error running tagreadbin");
 			return;
-		}			
+		}
 	} else {
 		if (!poll_for_ready (extractor, GST_STATE_PAUSED, TRUE, FALSE)) {
 			g_warning ("Error running decodebin");
@@ -942,14 +1071,14 @@ tracker_extract_gstreamer (const gchar *uri,
 	album = NULL;
 	scount = NULL;
 
-	extract_metadata (extractor, uri, metadata, &album, &scount);
+	extract_metadata (extractor, uri, preupdate, metadata, &album, &scount);
 
-	tracker_albumart_process (extractor->album_art_data, 
-				  extractor->album_art_size, 
-				  extractor->album_art_mime,
-				  /* g_hash_table_lookup (metadata, "Audio:Artist") */ NULL,
-				  album,
-				  uri);
+	tracker_albumart_process (extractor->album_art_data,
+	                          extractor->album_art_size,
+	                          extractor->album_art_mime,
+	                          /* g_hash_table_lookup (metadata, "Audio:Artist") */ NULL,
+	                          album,
+	                          uri);
 
 	g_free (scount);
 	g_free (album);
@@ -968,31 +1097,39 @@ tracker_extract_gstreamer (const gchar *uri,
 
 
 static void
-extract_gstreamer_audio (const gchar *uri, TrackerSparqlBuilder *metadata)
+extract_gstreamer_audio (const gchar          *uri,
+                         TrackerSparqlBuilder *preupdate,
+			 TrackerSparqlBuilder *metadata)
 {
-	tracker_extract_gstreamer (uri, metadata, EXTRACT_MIME_AUDIO);
+	tracker_extract_gstreamer (uri, preupdate, metadata, EXTRACT_MIME_AUDIO);
 }
 
 static void
-extract_gstreamer_video (const gchar *uri, TrackerSparqlBuilder *metadata)
+extract_gstreamer_video (const gchar          *uri,
+                         TrackerSparqlBuilder *preupdate,
+			 TrackerSparqlBuilder *metadata)
 {
-	tracker_extract_gstreamer (uri, metadata, EXTRACT_MIME_VIDEO);
+	tracker_extract_gstreamer (uri, preupdate, metadata, EXTRACT_MIME_VIDEO);
 }
 
 static void
-extract_gstreamer_image (const gchar *uri, TrackerSparqlBuilder *metadata)
+extract_gstreamer_image (const gchar          *uri,
+                         TrackerSparqlBuilder *preupdate,
+			 TrackerSparqlBuilder *metadata)
 {
-	tracker_extract_gstreamer (uri, metadata, EXTRACT_MIME_IMAGE);
+	tracker_extract_gstreamer (uri, preupdate, metadata, EXTRACT_MIME_IMAGE);
 }
 
 static void
-extract_gstreamer_3gpp (const gchar *uri, TrackerSparqlBuilder *metadata)
+extract_gstreamer_3gpp (const gchar          *uri,
+                        TrackerSparqlBuilder *preupdate,
+			TrackerSparqlBuilder *metadata)
 {
-	tracker_extract_gstreamer (uri, metadata, EXTRACT_MIME_3GPP);
+	tracker_extract_gstreamer (uri, preupdate, metadata, EXTRACT_MIME_3GPP);
 }
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
