@@ -36,10 +36,9 @@
 #include <libtracker-common/tracker-file-utils.h>
 #include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-os-dependant.h>
-#include <libtracker-common/tracker-statement-list.h>
 #include <libtracker-common/tracker-ontology.h>
 
-#include "tracker-main.h"
+#include <libtracker-extract/tracker-extract.h>
 
 #ifndef HAVE_GETLINE
 
@@ -56,15 +55,17 @@
 #endif /* HAVE_GETLINE */
 
 #ifdef USING_UNZIPPSFILES
-static void extract_ps_gz (const gchar *uri,
+static void extract_ps_gz (const gchar          *uri,
+                           TrackerSparqlBuilder *preupdate,
                            TrackerSparqlBuilder *metadata);
 #endif
-static void extract_ps    (const gchar *uri,
+static void extract_ps    (const gchar          *uri,
+                           TrackerSparqlBuilder *preupdate,
                            TrackerSparqlBuilder *metadata);
 
 static TrackerExtractData data[] = {
 #ifdef USING_UNZIPPSFILES
-	{ "application/x-gzpostscript",         extract_ps_gz },
+	{ "application/x-gzpostscript", extract_ps_gz },
 #endif /* USING_UNZIPPSFILES */
 	{ "application/postscript",     extract_ps    },
 	{ NULL, NULL }
@@ -206,6 +207,7 @@ date_to_iso8601 (const gchar *date)
 
 static void
 extract_ps (const gchar          *uri,
+            TrackerSparqlBuilder *preupdate,
             TrackerSparqlBuilder *metadata)
 {
 	FILE *f;
@@ -225,7 +227,6 @@ extract_ps (const gchar          *uri,
 	line = NULL;
 	length = 0;
 
-	tracker_sparql_builder_subject_iri (metadata, uri);
 	tracker_sparql_builder_predicate (metadata, "a");
 	tracker_sparql_builder_object (metadata, "nfo:PaginatedTextDocument");
 
@@ -292,6 +293,7 @@ extract_ps (const gchar          *uri,
 
 static void
 extract_ps_gz (const gchar          *uri,
+               TrackerSparqlBuilder *preupdate,
                TrackerSparqlBuilder *metadata)
 {
 	FILE *fz, *f;
@@ -381,7 +383,7 @@ extract_ps_gz (const gchar          *uri,
 		fclose (f);
 	}
 
-	extract_ps (gunzipped, metadata);
+	extract_ps (gunzipped, preupdate, metadata);
 	g_unlink (gunzipped);
 	g_free (filename);
 }
@@ -389,7 +391,7 @@ extract_ps_gz (const gchar          *uri,
 #endif /* USING_UNZIPPSFILES */
 
 TrackerExtractData *
-tracker_get_extract_data (void)
+tracker_extract_get_data (void)
 {
 	return data;
 }
